"use strict";

var _cssTree = _interopRequireDefault(require("css-tree"));

var _cssMediaquery = _interopRequireDefault(require("css-mediaquery"));

var _debug = _interopRequireDefault(require("debug"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debuglog = (0, _debug.default)('penthouse:preformatting:nonMatchingMediaQueryRemover'); // Only filters out:
//  - invalid media queries (that cannot be parsed)
//  - media-type: @print, @speech
//  - feature: width/height, only when
//    - used with `min` modifier(s)
//    - (any) value is smaller than corresponding width/height in matchConfig
// _All_ other media queries are kept

function keepMediaQuery(mediaQuery, matchConfig) {
  let mediaAST;

  try {
    mediaAST = _cssMediaquery.default.parse(mediaQuery);
  } catch (e) {
    // cant parse, most likely browser cant either
    return false;
  }

  return mediaAST.some(mq => {
    const isInverse = mq.inverse || mq.type === 'not';
    const hasNonMatchingDimensionFeatureExpression = mq.expressions.some(({
      modifier,
      feature,
      value
    }) => {
      if (modifier === 'min' && (feature === 'width' || feature === 'height')) {
        const constructedQuery = `(min-${feature}: ${value})`;
        return !_cssMediaquery.default.match(constructedQuery, matchConfig);
      }

      return false;
    });
    const shouldBeFiltered = mq.type === 'print' || mq.type === 'speech' || hasNonMatchingDimensionFeatureExpression;

    if (isInverse && shouldBeFiltered || !isInverse && !shouldBeFiltered) {
      return true;
    } else {
      return false;
    }
  });
}

function nonMatchingMediaQueryRemover(ast, width, height, keepLargerMediaQueries = false) {
  debuglog('BEFORE');
  const matchConfig = {
    type: 'screen',
    width: width + 'px',
    height: height + 'px'
  };
  const matchLargerMQConfig = {
    type: 'screen',
    width: '99999px',
    height: '99999px'
  };
  debuglog('matchConfig: ' + JSON.stringify(matchConfig, null, 2) + '\n' + 'keepLargerMediaQueries: ' + keepLargerMediaQueries);

  _cssTree.default.walk(ast, {
    visit: 'Atrule',
    enter: (atrule, item, list) => {
      // ignore (keep) all non media query rules
      if (_cssTree.default.keyword(atrule.name).name !== 'media') {
        return;
      } // this can happen - why? (atrule.prelude === null)
      // and should we remove this rule here, or keep it?


      if (!atrule.prelude) {
        return;
      }

      const mediaQuery = _cssTree.default.generate(atrule.prelude); // ismatching true then mq must be kept
      // if keep larger mq, keep if matching OR matching matchKeepLargeConfig


      const shouldKeep = keepLargerMediaQueries ? keepMediaQuery(mediaQuery, matchConfig) || keepMediaQuery(mediaQuery, matchLargerMQConfig) : keepMediaQuery(mediaQuery, matchConfig);

      if (!shouldKeep) {
        debuglog('DROP: ' + `(${mediaQuery}), `);
        list.remove(item);
      } else {
        debuglog('KEEP: ' + `(${mediaQuery}), `);
      }
    }
  });

  return ast;
}

module.exports = nonMatchingMediaQueryRemover;